@@ -19,7 +19,7 @@
 plot.see_check_heteroscedasticity <- function(x,
                                               data = NULL,
                                               size_point = 2,
-                                              size_line = 0.8,
+                                              linewidth = 0.8,
                                               size_title = 12,
                                               size_axis_title = base_size,
                                               base_size = 10,
@@ -79,7 +79,7 @@ plot.see_check_heteroscedasticity <- function(x,
   .plot_diag_homogeneity(
     dat,
     size_point = size_point,
-    size_line = size_line,
+    linewidth = linewidth,
     base_size = base_size,
     size_title = size_title,
     size_axis_title = size_axis_title,
