@@ -20,8 +20,8 @@ plot.see_effectsize_table <- function(x, ...) {
   x$Parameter <- factor(x$Parameter, levels = rev(unique(x$Parameter)))
 
   es_name <- colnames(x)[effectsize::is_effectsize_name(colnames(x))]
-  es_lab <- gsub("_", " ", es_name)
-  es_lab <- gsub("partial", "(partial)", es_lab)
+  es_lab <- gsub("_", " ", es_name, fixed = TRUE)
+  es_lab <- gsub("partial", "(partial)", es_lab, fixed = TRUE)
 
   x$.es <- x[, es_name]
 
@@ -67,8 +67,8 @@ plot.see_equivalence_test_effectsize <- function(x, ...) {
   }
 
   es_name <- colnames(x)[effectsize::is_effectsize_name(colnames(x))]
-  es_lab <- gsub("_", " ", es_name)
-  es_lab <- gsub("partial", "(partial)", es_lab)
+  es_lab <- gsub("_", " ", es_name, fixed = TRUE)
+  es_lab <- gsub("partial", "(partial)", es_lab, fixed = TRUE)
 
   x$.es <- x[, es_name]
 
