@@ -6,7 +6,7 @@
 #' @param colors Character vector of length two, indicating the colors (in
 #' hex-format) used when only one parameter is plotted, resp. when panels
 #' are plotted as facets.
-#' @param line_alpha Numeric value specifying alpha of lines indicating the
+#' @param alpha_line Numeric value specifying alpha of lines indicating the
 #' emphasized compatibility interval levels (see `?parameters::p_function`).
 #'
 #' @inheritParams data_plot
@@ -29,9 +29,9 @@
 plot.see_p_function <- function(x,
                                 colors = c("black", "#1b6ca8"),
                                 size_point = 1.2,
-                                size_line = c(0.7, 0.9),
+                                linewidth = c(0.7, 0.9),
                                 size_text = 3,
-                                line_alpha = 0.15,
+                                alpha_line = 0.15,
                                 show_labels = TRUE,
                                 n_columns = NULL,
                                 show_intercept = FALSE,
@@ -55,6 +55,12 @@ plot.see_p_function <- function(x,
   # make sure group is factor
   data_ci_segments$group <- as.factor(data_ci_segments$group)
 
+  # sanity check - linewidth must be of length two, when we have more than
+  # one group (i.e. when we emphasize CI lines)
+  if (length(linewidth) != 2 && insight::n_unique(data_ci_segments$group) == 2) {
+    insight::format_error("Length of `linewidth` must of length 2, to match regular and emphasized interval lines.") # nolint
+  }
+
   # setup - no color/fill aes for ribbons when we have no facets
   if (!is.null(n_columns) || insight::n_unique(data_ribbon$Parameter) == 1) {
     p <- ggplot2::ggplot() +
@@ -97,7 +103,7 @@ plot.see_p_function <- function(x,
       ),
       colour = colors[1],
       size = size_point,
-      alpha = line_alpha,
+      alpha = alpha_line,
       show.legend = FALSE
     ) +
     # points for vertical CI bars
@@ -110,7 +116,7 @@ plot.see_p_function <- function(x,
       ),
       colour = colors[1],
       size = size_point,
-      alpha = line_alpha,
+      alpha = alpha_line,
       show.legend = FALSE
     ) +
     # lines for vertical CI bars
@@ -125,7 +131,7 @@ plot.see_p_function <- function(x,
         linewidth = .data$group
       ),
       colour = colors[1],
-      alpha = line_alpha,
+      alpha = alpha_line,
       show.legend = FALSE
     )
 
@@ -162,7 +168,7 @@ plot.see_p_function <- function(x,
     # labelling
     ggplot2::labs(y = expression(paste(italic("p"), "-value")), x = "Range of Estimates", colour = NULL) +
     theme_lucid() +
-    ggplot2::scale_linewidth_manual(values = size_line, guide = "none")
+    ggplot2::scale_linewidth_manual(values = linewidth, guide = "none")
 
   # facets for grids, different color/fill when no grids
   if (!is.null(n_columns)) {
