@@ -14,7 +14,7 @@
 #'
 #' @seealso See also the vignette about [`check_model()`](https://easystats.github.io/performance/articles/check_model.html).
 #'
-#' @examplesIf insight::check_if_installed("performance", "0.10.9.7") && require("glmmTMB") && require("qqplotr") && require("DHARMa")
+#' @examplesIf require("glmmTMB") && require("qqplotr") && require("DHARMa")
 #' data(Salamanders, package = "glmmTMB")
 #' model <- glmmTMB::glmmTMB(
 #'   count ~ mined + spp + (1 | site),
@@ -31,13 +31,13 @@
 #'
 #' @export
 plot.see_performance_simres <- function(x,
-                                        size_line = 0.8,
+                                        linewidth = 0.8,
                                         size_point = 2,
                                         size_title = 12,
                                         size_axis_title = base_size,
                                         base_size = 10,
                                         alpha = 0.2,
-                                        dot_alpha = 0.8,
+                                        alpha_dot = 0.8,
                                         colors = c("#3aaf85", "#1b6ca8"),
                                         detrend = FALSE,
                                         transform = NULL,
@@ -97,7 +97,7 @@ plot.see_performance_simres <- function(x,
       qqplotr::stat_qq_line(
         distribution = dfun,
         dparams = dp,
-        size = size_line,
+        size = linewidth,
         colour = colors[1],
         detrend = detrend
       ),
@@ -105,7 +105,7 @@ plot.see_performance_simres <- function(x,
         distribution = dfun,
         dparams = dp,
         size = size_point,
-        alpha = dot_alpha,
+        alpha = alpha_dot,
         colour = colors[2],
         detrend = detrend
       )
@@ -127,7 +127,7 @@ plot.see_performance_simres <- function(x,
         colour = colors[2]
       ),
       ggplot2::geom_qq_line(
-        linewidth = size_line,
+        linewidth = linewidth,
         colour = colors[1],
         na.rm = TRUE,
         distribution = dfun,
