@@ -1,6 +1,6 @@
 test_that("`plot.see_parameters_distribution()` works", {
   set.seed(333)
-  x <- sample(1:100, 1000, replace = TRUE)
+  x <- sample.int(100, 1000, replace = TRUE)
   result <- datawizard::describe_distribution(x)
   expect_s3_class(plot(result), "gg")
 
