@@ -1,6 +1,6 @@
 test_that("`plot.see_hdi()` works", {
-  skip_if_not_or_load_if_installed("rstanarm")
-  skip_if_not_or_load_if_installed("ggridges")
+  skip_if_not_installed("rstanarm")
+  skip_if_not_installed("ggridges")
 
   set.seed(123)
   result <- bayestestR::hdi(m_rstan)
