@@ -14,4 +14,10 @@ test_that("`plot.see_n_factors()` works", {
     title = "line graph",
     fig = plot(result, type = "line")
   )
+
+  set.seed(123)
+  vdiffr::expect_doppelganger(
+    title = "area graph",
+    fig = plot(result, type = "area")
+  )
 })
