@@ -12,8 +12,9 @@ skip_on_cran()
 skip_if_not_installed("bayestestR", minimum_version = "0.14.1")
 skip_if_not_installed("parameters", minimum_version = "0.22.3")
 
-test_that("`plot.see_p_direction works {parameters}}", {
-  skip_if_not_installed("vdiffr")
+test_that("`plot.see_p_direction` works {parameters}", {
+  skip_if_not_installed("ggridges")
+
   data(qol_cancer, package = "parameters")
   model <- lm(QoL ~ time + age + education, data = qol_cancer)
   set.seed(123)
@@ -32,6 +33,8 @@ test_that("`plot.see_p_direction works {parameters}}", {
 
 test_that("plot p_direction, glmmTMB", {
   skip_if_not_installed("glmmTMB")
+  skip_if_not_installed("ggridges")
+
   data(Salamanders, package = "glmmTMB")
   m1 <- glmmTMB::glmmTMB(count ~ mined + cover + (1 | site),
     zi = ~mined,
