@@ -1,7 +1,4 @@
 test_that("scale_fill_colorhex works as expected", {
-  skip_if_not_or_load_if_installed("vdiffr")
-  skip_if(getRversion() < "4.1")
-
   set.seed(123)
   vdiffr::expect_doppelganger(
     title = "scale_fill_colorhex_d works",
